@@ -109,6 +109,10 @@ if ARGS.create:
         from test_definition_template import common
 
         copy_tree(common.__path__[0], './test_definitions/common')
+
+        import dist_files
+        from shutil import copyfile
+        copyfile(dist_files.__path__[0] + '/Dockerfile', './Dockerfile')
     else:
         print('./test_definitions/common already exists. Not copying it.')
 
