@@ -7,9 +7,9 @@ import gaiaclient
 # Thus it is not good idea to connect to instrument here
 # connect at instrument_initialization instead.
 
-INSTRUMENTS = {"G5": None}
+INSTRUMENTS = {"gaia": None}
 
 
 def instrument_initialization():
     """Connect and initialize instruments"""
-    INSTRUMENTS["G5"] = gaiaclient.Client("http://localhost:1234")
+    INSTRUMENTS["gaia"] = gaiaclient.Client("http://localhost:1234")
